==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/partdefault_001/PartDefault.java <==

package net.datastream.schemas.mp_entities.partdefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRACKMETHOD"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYASSET"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYLOT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KIT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PREVENTREORDERS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUGITIVEGAS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRACKBYCONDITION"/>
 *       &lt;/sequence>
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "organizationid",
    "trackmethod",
    "pricetype",
    "currencyid",
    "byasset",
    "bylot",
    "kit",
    "outofservice",
    "preventreorders",
    "fugitivegas",
    "trackbycondition"
})
@XmlRootElement(name = "PartDefault")
public class PartDefault {

    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "TRACKMETHOD", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type trackmethod;
    @XmlElement(name = "PRICETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type pricetype;
    @XmlElement(name = "CURRENCYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type currencyid;
    @XmlElement(name = "BYASSET", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String byasset;
    @XmlElement(name = "BYLOT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String bylot;
    @XmlElement(name = "KIT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String kit;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "PREVENTREORDERS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String preventreorders;
    @XmlElement(name = "FUGITIVEGAS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String fugitivegas;
    @XmlElement(name = "TRACKBYCONDITION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String trackbycondition;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété trackmethod.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTRACKMETHOD() {
        return trackmethod;
    }

    /**
     * Définit la valeur de la propriété trackmethod.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTRACKMETHOD(TYPE_Type value) {
        this.trackmethod = value;
    }

    /**
     * Obtient la valeur de la propriété pricetype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getPRICETYPE() {
        return pricetype;
    }

    /**
     * Définit la valeur de la propriété pricetype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setPRICETYPE(TYPE_Type value) {
        this.pricetype = value;
    }

    /**
     * Obtient la valeur de la propriété currencyid.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Définit la valeur de la propriété currencyid.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

    /**
     * Obtient la valeur de la propriété byasset.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYASSET() {
        return byasset;
    }

    /**
     * Définit la valeur de la propriété byasset.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYASSET(String value) {
        this.byasset = value;
    }

    /**
     * Obtient la valeur de la propriété bylot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYLOT() {
        return bylot;
    }

    /**
     * Définit la valeur de la propriété bylot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYLOT(String value) {
        this.bylot = value;
    }

    /**
     * Obtient la valeur de la propriété kit.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKIT() {
        return kit;
    }

    /**
     * Définit la valeur de la propriété kit.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKIT(String value) {
        this.kit = value;
    }

    /**
     * Obtient la valeur de la propriété outofservice.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Définit la valeur de la propriété outofservice.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Obtient la valeur de la propriété preventreorders.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREVENTREORDERS() {
        return preventreorders;
    }

    /**
     * Définit la valeur de la propriété preventreorders.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREVENTREORDERS(String value) {
        this.preventreorders = value;
    }

    /**
     * Obtient la valeur de la propriété fugitivegas.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUGITIVEGAS() {
        return fugitivegas;
    }

    /**
     * Définit la valeur de la propriété fugitivegas.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUGITIVEGAS(String value) {
        this.fugitivegas = value;
    }

    /**
     * Obtient la valeur de la propriété trackbycondition.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRACKBYCONDITION() {
        return trackbycondition;
    }

    /**
     * Définit la valeur de la propriété trackbycondition.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRACKBYCONDITION(String value) {
        this.trackbycondition = value;
    }

    /**
     * Obtient la valeur de la propriété user_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Définit la valeur de la propriété user_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Obtient la valeur de la propriété system_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Définit la valeur de la propriété system_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/partdefault_001/PartDefault.java <==

package net.datastream.schemas.mp_entities.partdefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRACKMETHOD"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYASSET"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYLOT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KIT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PREVENTREORDERS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUGITIVEGAS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRACKBYCONDITION"/>
 *       &lt;/sequence>
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "organizationid",
    "trackmethod",
    "pricetype",
    "currencyid",
    "byasset",
    "bylot",
    "kit",
    "outofservice",
    "preventreorders",
    "fugitivegas",
    "trackbycondition"
})
@XmlRootElement(name = "PartDefault")
public class PartDefault {

    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "TRACKMETHOD", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type trackmethod;
    @XmlElement(name = "PRICETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type pricetype;
    @XmlElement(name = "CURRENCYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type currencyid;
    @XmlElement(name = "BYASSET", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String byasset;
    @XmlElement(name = "BYLOT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String bylot;
    @XmlElement(name = "KIT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String kit;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "PREVENTREORDERS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String preventreorders;
    @XmlElement(name = "FUGITIVEGAS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String fugitivegas;
    @XmlElement(name = "TRACKBYCONDITION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String trackbycondition;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the trackmethod property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTRACKMETHOD() {
        return trackmethod;
    }

    /**
     * Sets the value of the trackmethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTRACKMETHOD(TYPE_Type value) {
        this.trackmethod = value;
    }

    /**
     * Gets the value of the pricetype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getPRICETYPE() {
        return pricetype;
    }

    /**
     * Sets the value of the pricetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setPRICETYPE(TYPE_Type value) {
        this.pricetype = value;
    }

    /**
     * Gets the value of the currencyid property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Sets the value of the currencyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

    /**
     * Gets the value of the byasset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYASSET() {
        return byasset;
    }

    /**
     * Sets the value of the byasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYASSET(String value) {
        this.byasset = value;
    }

    /**
     * Gets the value of the bylot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYLOT() {
        return bylot;
    }

    /**
     * Sets the value of the bylot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYLOT(String value) {
        this.bylot = value;
    }

    /**
     * Gets the value of the kit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKIT() {
        return kit;
    }

    /**
     * Sets the value of the kit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKIT(String value) {
        this.kit = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the preventreorders property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREVENTREORDERS() {
        return preventreorders;
    }

    /**
     * Sets the value of the preventreorders property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREVENTREORDERS(String value) {
        this.preventreorders = value;
    }

    /**
     * Gets the value of the fugitivegas property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUGITIVEGAS() {
        return fugitivegas;
    }

    /**
     * Sets the value of the fugitivegas property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUGITIVEGAS(String value) {
        this.fugitivegas = value;
    }

    /**
     * Gets the value of the trackbycondition property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRACKBYCONDITION() {
        return trackbycondition;
    }

    /**
     * Sets the value of the trackbycondition property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRACKBYCONDITION(String value) {
        this.trackbycondition = value;
    }

    /**
     * Gets the value of the user_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Sets the value of the user_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Gets the value of the system_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Sets the value of the system_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}
